@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -19,6 +30,7 @@
 
 #include <ghemical/eng2_qm_mm.h>
 
+#include <cstring>	// required by gcc-4.3
 #include <iomanip>
 #include <sstream>
 using namespace std;
@@ -52,7 +64,7 @@ cout << "model::ReadStream_OLD() : starting file input." << endl;
 		
 		element el = element(tmp2[1]);
 		atom newatom(el, tmp4, prj.GetCRDSetCount());
-		prj.AddAtom(newatom); tmp1.push_back(& prj.GetLastAtom());
+		prj.AddAtom_lg(newatom); tmp1.push_back(& prj.GetLastAtom());
 		
 		for (i32s n1 = 0;n1 < tmp2[0];n1++)
 		{
@@ -164,7 +176,7 @@ if (n1 != ar_vector.size()) cout << "WARNING : bad atom id numbers!!!" << endl;
 				
 				if (selected) newatom.flags |= ATOMFLAG_USER_SELECTED;
 				
-				prj.AddAtom(newatom);
+				prj.AddAtom_lg(newatom);
 
 				ar_vector.push_back(& prj.GetLastAtom());
 				
@@ -368,7 +380,7 @@ if (n1 != ar_vector.size()) cout << "WARNING : atom id number mismatch!!!" << en
 				newatom.flags = n3;
 				if (selected) newatom.flags |= ATOMFLAG_USER_SELECTED;
 				
-				prj.AddAtom(newatom);
+				prj.AddAtom_lg(newatom);
 
 				ar_vector.push_back(& prj.GetLastAtom());
 				
@@ -468,7 +480,7 @@ if (n1 >= ar_vector.size()) { cout << "ERROR : invalid atom id number!!!" << end
 	
 	if (!newsu && !strcmp(setup1_qm::static_GetClassName(), su_cn)) newsu = new setup1_qm(& prj);
 	if (!newsu && !strcmp(setup1_mm::static_GetClassName(), su_cn)) newsu = new setup1_mm(& prj);
-	if (!newsu && !strcmp(setup1_sf::static_GetClassName(), su_cn)) newsu = new setup1_sf(& prj, false);
+	//if (!newsu && !strcmp(setup1_sf::static_GetClassName(), su_cn)) newsu = new setup1_sf(& prj, false);
 	
 	if (!newsu && !strcmp(setup2_qm_mm::static_GetClassName(), su_cn)) newsu = new setup2_qm_mm(& prj);
 	
@@ -657,7 +669,7 @@ if (n1 != ar_vector.size()) cout << "WARNING : atom id number mismatch!!!" << en
 				newatom.flags = (n4 & 0xFF);	// skip internal...
 				if (selected) newatom.flags |= ATOMFLAG_USER_SELECTED;
 				
-				prj.AddAtom(newatom);
+				prj.AddAtom_lg(newatom);
 
 				ar_vector.push_back(& prj.GetLastAtom());
 				
@@ -757,7 +769,7 @@ if (n1 >= ar_vector.size()) { cout << "ERROR : invalid atom id number!!!" << end
 	
 	if (!newsu && !strcmp(setup1_qm::static_GetClassName(), su_cn)) newsu = new setup1_qm(& prj);
 	if (!newsu && !strcmp(setup1_mm::static_GetClassName(), su_cn)) newsu = new setup1_mm(& prj);
-	if (!newsu && !strcmp(setup1_sf::static_GetClassName(), su_cn)) newsu = new setup1_sf(& prj, false);
+	//if (!newsu && !strcmp(setup1_sf::static_GetClassName(), su_cn)) newsu = new setup1_sf(& prj, false);
 	
 	if (!newsu && !strcmp(setup2_qm_mm::static_GetClassName(), su_cn)) newsu = new setup2_qm_mm(& prj);
 	
@@ -945,7 +957,7 @@ Please use the File/Export to generate OpenBabel-compatible files.");
 	
 	file << "!Info ";
 	file << prj.GetCRDSetCount() << " ";
-	file << prj.GetCurrentSetup()->GetClassName() << " ";
+	file << prj.GetCurrentSetup()->GetClassName_lg() << " ";
 	file << prj.GetCurrentSetup()->GetEngineIDNumber(prj.GetCurrentSetup()->GetCurrEngIndex()) << endl;	// these values might change in future versions?!?!?!
 	
 	// write "!Atoms" section. write the number of atoms,
