@@ -2,8 +2,19 @@
 
 // Copyright (C) 2003 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -15,8 +26,9 @@
 
 #include <ghemical/utility.h>
 
-#include <string.h>
+#ifndef WIN32
 #include <X11/Xlib.h>	// DisplayString()
+#endif	// WIN32
 
 #include "res_gtk/draw.xpm"
 #include "res_gtk/erase.xpm"
@@ -37,6 +49,8 @@
 
 #include "gtk_wnd.h"
 
+//#include <string.h>
+#include <cstring>	// required by gcc-4.3
 #include <sstream>
 using namespace std;
 
@@ -75,10 +89,11 @@ GtkActionEntry gtk_app::entries1[] =
 	
 	{ "New", GTK_STOCK_NEW, "_New", "<control>N", "New file", (GCallback) gtk_app::mainmenu_FileNew },
 	{ "Open", GTK_STOCK_OPEN, "_Open", "<control>O", "Open a file", (GCallback) gtk_app::mainmenu_FileOpen },
+	{ "SaveAs", GTK_STOCK_OPEN, "_Save as...", "<control>O", "Save a file", (GCallback) gtk_app::mainmenu_FileSaveAs },
 	{ "Close", GTK_STOCK_QUIT, "_Close", "<control>C", "Quit the program", (GCallback) gtk_app::mainmenu_FileClose },
 	
 	{ "Help", NULL, "_Help", "<control>H", "View the User's Manual", (GCallback) gtk_app::mainmenu_HelpHelp },
-	{ "About", NULL, "_About", "<control>A", "View the copyright notices", (GCallback) gtk_app::mainmenu_HelpAbout },
+	{ "About", NULL, "_About", "<control>A", "View the Copyright notices", (GCallback) gtk_app::mainmenu_HelpAbout },
 	
 	// the rest are toolbar actions...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -111,6 +126,8 @@ const char * gtk_app::ui_description =
 "      <menuitem action='New'/>"
 "      <menuitem action='Open'/>"
 "      <separator/>"
+"      <menuitem action='SaveAs'/>"
+"      <separator/>"
 "      <menuitem action='Close'/>"
 "    </menu>"
 "    <menu action='HelpMenu'>"
@@ -324,7 +341,7 @@ gtk_window_set_title(GTK_WINDOW(main_window), tmp_title);
 free(tmp_title); tmp_title = NULL;
 	
 	ostringstream icon_fn;
-	icon_fn << APPDATA_PATH << DIR_SEPARATOR << APPVERSION << DIR_SEPARATOR << "pixmaps" << DIR_SEPARATOR << "ghemical.png" << ends;
+	icon_fn << project::appdata_path << DIR_SEPARATOR << APPVERSION << DIR_SEPARATOR << "pixmaps" << DIR_SEPARATOR << "ghemical.png" << ends;
 	pixbuf = gdk_pixbuf_new_from_file(icon_fn.str().c_str(), NULL);
 	if (pixbuf == NULL) printf("Error Loading Icon: %s\n", icon_fn.str().c_str());
 	else gtk_window_set_icon(GTK_WINDOW(main_window), pixbuf);
@@ -735,6 +752,8 @@ void gtk_app::SetNewProject(void)
 
 gboolean gtk_app::DeleteEventHandler(GtkWidget * widget, GdkEvent * event, gpointer data)
 {
+	if (project::background_job_running) return TRUE;	// protect the model-data during background jobs...
+	
 	bool quit = sQuestion("Are you sure that you\nwant to quit the program?");
 	if (quit) return FALSE; else return TRUE;
 }
@@ -796,22 +815,27 @@ bool gtk_app::sQuestion(const char * msg)
 	}
 }
 
+#define MSG_BUFF_SZ	65536
+
 void gtk_app::sPrintToLog(const char * msg)
 {
-	static int msgcounter = 0;
-	static char msgbuff[4][1024];
+	if (strlen(msg) > MSG_BUFF_SZ)
+	{
+		cout << "gtk_app::sPrintToLog() : message is too long!" << endl;
+		return;
+	}
 	
-	strcpy(msgbuff[msgcounter], msg);
+	static char msgbuff[MSG_BUFF_SZ];
+	strcpy(msgbuff, msg);
 	
 	GtkTextIter txt_iter;
 	gtk_text_buffer_get_iter_at_mark(txt_buffer, & txt_iter, end_mark);
 	
-	gtk_text_buffer_insert(txt_buffer, & txt_iter, msgbuff[msgcounter], -1);
+	gtk_text_buffer_insert(txt_buffer, & txt_iter, msgbuff, -1);
 	
 	gtk_text_view_scroll_mark_onscreen(GTK_TEXT_VIEW(txt_widget), end_mark);
 	
-	cout << "PrintToLog[" << msgcounter << "] : " << msg;
-	if (++msgcounter >= 4) msgcounter = 0;
+	cout << "PrintToLog : " << msg;
 }
 
 void gtk_app::Message(const char * msg)
@@ -1122,6 +1146,8 @@ void gtk_app::ObjectRemoved(ogl_smart_object * p1)
 
 gint gtk_app::ViewsObjsPopupHandler(GtkWidget * widget, GdkEvent * event)
 {
+	if (project::background_job_running) return TRUE;	// protect the model-data during background jobs...
+	
 	if (event->type == GDK_BUTTON_PRESS)
 	{
 		GdkEventButton * event_button = (GdkEventButton *) event;
@@ -1324,6 +1350,8 @@ void gtk_app::ClearChainsView(void)
 
 gint gtk_app::ChainsPopupHandler(GtkWidget * widget, GdkEvent * event)
 {
+	if (project::background_job_running) return TRUE;	// protect the model-data during background jobs...
+	
 	if (event->type == GDK_BUTTON_PRESS)
 	{
 		GdkEventButton * event_button = (GdkEventButton *) event;
@@ -1432,6 +1460,8 @@ void gtk_app::AtomRemoved(atom * p1)
 
 gint gtk_app::AtomsPopupHandler(GtkWidget * widget, GdkEvent * event)
 {
+	if (project::background_job_running) return TRUE;	// protect the model-data during background jobs...
+	
 	if (event->type == GDK_BUTTON_PRESS)
 	{
 		GdkEventButton * event_button = (GdkEventButton *) event;
@@ -1548,6 +1578,8 @@ void gtk_app::BondRemoved(bond * p1)
 
 gint gtk_app::BondsPopupHandler(GtkWidget * widget, GdkEvent * event)
 {
+	if (project::background_job_running) return TRUE;	// protect the model-data during background jobs...
+	
 	if (event->type == GDK_BUTTON_PRESS)
 	{
 		GdkEventButton * event_button = (GdkEventButton *) event;
@@ -1898,6 +1930,8 @@ void gtk_app::maintb_dial_BondType(gpointer, guint, GtkWidget *)
 
 void gtk_app::maintb_dial_Setup(gpointer, guint, GtkWidget *)
 {
+	if (project::background_job_running) return;	// protect the model-data during background jobs...
+	
 	new gtk_setup_dialog(GetPrjX());	// will call delete itself...
 }
 
@@ -1907,18 +1941,31 @@ void gtk_app::maintb_dial_Setup(gpointer, guint, GtkWidget *)
 
 void gtk_app::mainmenu_FileNew(gpointer, guint, GtkWidget *)
 {
+	if (project::background_job_running) return;	// protect the model-data during background jobs...
+	
 	GetAppX()->SetNewProject();
 }
 
 void gtk_app::mainmenu_FileOpen(gpointer, guint, GtkWidget *)
 {
+	if (project::background_job_running) return;	// protect the model-data during background jobs...
+	
 	new gtk_file_open_dialog(GetPrjX());	// will call delete itself...
 }
 
+void gtk_app::mainmenu_FileSaveAs(gpointer, guint, GtkWidget *)
+{
+	if (project::background_job_running) return;	// protect the model-data during background jobs...
+	
+	new gtk_file_save_dialog(GetPrjX());	// will call delete itself...
+}
+
 void gtk_app::mainmenu_FileClose(gpointer, guint, GtkWidget *)
 {
-// gtk_signal_emit_by_name(GTK_OBJECT(main_window), "delete_event");
-// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	if (project::background_job_running) return;	// protect the model-data during background jobs...
+	
+	// gtk_signal_emit_by_name(GTK_OBJECT(main_window), "delete_event");
+	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	// the above is an "elegant" solution but it segfaults ; why???
 	// in below the same stuff is done "manually".
 	
