@@ -2,8 +2,19 @@
 
 // Copyright (C) 2005 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -28,15 +39,17 @@ GtkActionEntry gtk_oglview_wnd::entries[] =
 #ifdef ENABLE_OPENBABEL
 	{ "Import", GTK_STOCK_OPEN, "_Import...", "<control>I", "Import other file formats using OpenBabel", (GCallback) gtk_project::popup_FileImport },
 #endif	// ENABLE_OPENBABEL
-	{ "SaveAs", GTK_STOCK_SAVE, "_Save as...", "<control>S", "Save a file", (GCallback) gtk_project::popup_FileSaveAs },
+	{ "SaveAs", GTK_STOCK_SAVE, "_Save as...", "<control>S", "Save a file", (GCallback) gtk_app::mainmenu_FileSaveAs },
 #ifdef ENABLE_OPENBABEL
 	{ "Export", GTK_STOCK_SAVE, "_Export", "<control>E", "Export other file formats using OpenBabel", (GCallback) gtk_project::popup_FileExport },
 #endif	// ENABLE_OPENBABEL
+//	{ "ExportGraphics", GTK_STOCK_SAVE, "Export _Graphics", "<control>E", "Export graphics", (GCallback) gtk_project::popup_FileExportGraphics },
 	{ "Close", GTK_STOCK_QUIT, "_Close", "<control>C", "Close the file", (GCallback) gtk_app::mainmenu_FileClose },
 	
 	{ "FileExtraMenu", NULL, "_Extra Tools" },
 	// ^^^^^^^^^^^^^
-	{ "ImportPDB", NULL, "_Import PDB", NULL, "Import a PDB file", (GCallback) gtk_project::popup_FileExtra1 },
+	{ "FileExtra1", NULL, "_Import PDB", NULL, "Import a PDB file", (GCallback) gtk_project::popup_FileExtra1 },
+//	{ "FileExtra2", NULL, "_Import ???", NULL, "Import a ??? file", (GCallback) gtk_project::popup_FileExtra2 },
 	
 	{ "SelectMenu", NULL, "_Select" },
 	// ^^^^^^^^^^
@@ -193,9 +206,11 @@ const char * gtk_oglview_wnd::ui_description =
 #ifdef ENABLE_OPENBABEL
 "      <menuitem action='Export'/>"
 #endif	// ENABLE_OPENBABEL
+//"      <menuitem action='ExportGraphics'/>"
 "      <separator/>"
 "      <menu action='FileExtraMenu'>"
-"        <menuitem action='ImportPDB'/>"
+"        <menuitem action='FileExtra1'/>"
+//"        <menuitem action='FileExtra2'/>"
 "      </menu>"
 "      <separator/>"
 "      <menuitem action='Close'/>"
