@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -53,11 +64,7 @@ using namespace std;
 gtk_project::gtk_project(void) :
 	project()
 {
-#ifdef ENABLE_THREADS
-	
 	pd = NULL;
-	
-#endif	// ENABLE_THREADS
 }
 
 void gtk_project::DoSafeStart(void)
@@ -74,11 +81,7 @@ void gtk_project::DoSafeStart(void)
 
 gtk_project::~gtk_project(void)
 {
-#ifdef ENABLE_THREADS
-	
 	if (pd != NULL) cout << "MEM-LEAK pd" << endl;
-	
-#endif	// ENABLE_THREADS
 }
 
 oglview_wcl * gtk_project::GetClient(GtkWidget * widget)
@@ -99,34 +102,38 @@ oglview_wcl * gtk_project::GetClient(GtkWidget * widget)
 	return NULL;
 }
 
+#ifdef ENABLE_THREADS
+
 void gtk_project::ThreadLock(void)
 {
-#ifdef ENABLE_THREADS
-	
 	// this is a "technical" thread lock needed in GTK/GDK.
 	
 	// BUT in addition to this we need to make sure that the
 	// user interface is not accessed during any thread processing!
-	// we use a modal progress-dialog box to achieve this.
+	
+	// this means that user may not access menus or mouse tools during
+	// multithreaded computations ; see project::background_job_running
+	// for more about this...
 	
 	gdk_threads_enter();
-	
-#endif	// ENABLE_THREADS
 }
 
 void gtk_project::ThreadUnlock(void)
 {
-#ifdef ENABLE_THREADS
-	
 	gdk_threads_leave();
-	
-#endif	// ENABLE_THREADS
 }
 
+#else	// ENABLE_THREADS
+
+void gtk_project::NoThreadsIterate(void)
+{
+	while (gtk_events_pending()) gtk_main_iteration();
+}
+
+#endif	// ENABLE_THREADS
+
 bool gtk_project::SetProgress(double progress, double * graphdata)
 {
-#ifdef ENABLE_THREADS
-	
 	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(pd->progressbar_job), progress);
 	
 	if (graphdata != NULL)
@@ -143,16 +150,8 @@ bool gtk_project::SetProgress(double progress, double * graphdata)
 	}
 	
 	return pd->cancel;
-	
-#else	// ENABLE_THREADS
-	
-	return false;
-	
-#endif	// ENABLE_THREADS
 }
 
-#ifdef ENABLE_THREADS
-
 void gtk_project::CreateProgressDialog(const char * title, bool show_pbar, int graphs_n, int graphs_s)
 {
 	pd = new gtk_progress_dialog(title, show_pbar, graphs_n, graphs_s);
@@ -164,40 +163,23 @@ void gtk_project::DestroyProgressDialog(void)
 	delete pd; pd = NULL;
 }
 
-#endif	// ENABLE_THREADS
-
-void gtk_project::GeomOptGetParam(geomopt_param & param)
-{
-	new gtk_geomopt_dialog(& param);	// the object will call delete itself...
-	
-	// the above dialog is a modal one; we will return
-	// from the function only after the dialog is closed.
-	
-	cout << "now returning from gtk_project::GeomOptGetParam()." << endl;
-}
-
-void gtk_project::MolDynGetParam(moldyn_param & param)
-{
-	new gtk_moldyn_dialog(& param);		// the object will call delete itself...
-	
-	// the above dialog is a modal one; we will return
-	// from the function only after the dialog is closed.
-	
-	cout << "now returning from gtk_project::MolDynGetParam()." << endl;
-}
-
 void gtk_project::start_job_GeomOpt(jobinfo_GeomOpt * ji)
 {
+	if (ji->show_dialog)
+	{
+		new gtk_geomopt_dialog(& ji->go);	// the object will call delete itself...
+		cout << "now returning from gtk_project::GeomOptGetParam()." << endl;
+		
+		// the above dialog is (AND IT MUST BE) a modal one; we will return
+		// from the function only after the dialog is closed.
+	}
+	
+	if (!ji->go.GetConfirm()) return;
+	
 #ifdef ENABLE_THREADS
 	
-	CreateProgressDialog("Geometry Optimization", true, 1, 20);
 	GThread * t = g_thread_create(process_job_GeomOpt, (gpointer) ji, FALSE, NULL);
-	
-	if (t == NULL)
-	{
-		DestroyProgressDialog();
-		ErrorMessage("Thread creation failed : GeomOpt");
-	}
+	if (t == NULL) ErrorMessage("Thread creation failed : GeomOpt");
 	
 #else	// ENABLE_THREADS
 	
@@ -208,43 +190,46 @@ void gtk_project::start_job_GeomOpt(jobinfo_GeomOpt * ji)
 
 gpointer gtk_project::process_job_GeomOpt(gpointer p)
 {
+	project::background_job_running = true;
 	jobinfo_GeomOpt * ji = (jobinfo_GeomOpt *) p;
 	
+	ji->prj->ThreadLock();
+	ji->prj->CreateProgressDialog("Geometry Optimization", true, 1, 20);
+	ji->prj->ThreadUnlock();
+	
 #ifdef ENABLE_THREADS
-	
 	const bool updt = false;
-	
 #else	// ENABLE_THREADS
-	
 	const bool updt = true;
-	
 #endif	// ENABLE_THREADS
 	
 	ji->prj->DoGeomOpt(ji->go, updt);
 	
-#ifdef ENABLE_THREADS
-	
 	ji->prj->ThreadLock();
 	ji->prj->DestroyProgressDialog();
 	ji->prj->ThreadUnlock();
 	
-#endif	// ENABLE_THREADS
-	
+	project::background_job_running = false;
 	return NULL;
 }
 
 void gtk_project::start_job_MolDyn(jobinfo_MolDyn * ji)
 {
+	if (ji->show_dialog)
+	{
+		new gtk_moldyn_dialog(& ji->md);		// the object will call delete itself...
+		cout << "now returning from gtk_project::MolDynGetParam()." << endl;
+		
+		// the above dialog is (AND IT MUST BE) a modal one; we will return
+		// from the function only after the dialog is closed.
+	}
+	
+	if (!ji->md.GetConfirm()) return;
+	
 #ifdef ENABLE_THREADS
 	
-	CreateProgressDialog("Molecular Dynamics", true, NOT_DEFINED, NOT_DEFINED);
 	GThread * t = g_thread_create(process_job_MolDyn, (gpointer) ji, FALSE, NULL);
-	
-	if (t == NULL)
-	{
-		DestroyProgressDialog();
-		ErrorMessage("Thread creation failed : MolDyn");
-	}
+	if (t == NULL) ErrorMessage("Thread creation failed : MolDyn");
 	
 #else	// ENABLE_THREADS
 	
@@ -255,28 +240,26 @@ void gtk_project::start_job_MolDyn(jobinfo_MolDyn * ji)
 
 gpointer gtk_project::process_job_MolDyn(gpointer p)
 {
+	project::background_job_running = true;
 	jobinfo_MolDyn * ji = (jobinfo_MolDyn *) p;
 	
+	ji->prj->ThreadLock();
+	ji->prj->CreateProgressDialog("Molecular Dynamics", true, NOT_DEFINED, NOT_DEFINED);
+	ji->prj->ThreadUnlock();
+
 #ifdef ENABLE_THREADS
-	
 	const bool updt = false;
-	
 #else	// ENABLE_THREADS
-	
 	const bool updt = true;
-	
 #endif	// ENABLE_THREADS
 	
 	ji->prj->DoMolDyn(ji->md, updt);
 	
-#ifdef ENABLE_THREADS
-	
 	ji->prj->ThreadLock();
 	ji->prj->DestroyProgressDialog();
 	ji->prj->ThreadUnlock();
 	
-#endif	// ENABLE_THREADS
-	
+	project::background_job_running = false;
 	return NULL;
 }
 
@@ -284,14 +267,8 @@ void gtk_project::start_job_RandomSearch(jobinfo_RandomSearch * ji)
 {
 #ifdef ENABLE_THREADS
 	
-	CreateProgressDialog("Random Search", true, NOT_DEFINED, NOT_DEFINED);
 	GThread * t = g_thread_create(process_job_RandomSearch, (gpointer) ji, FALSE, NULL);
-	
-	if (t == NULL)
-	{
-		DestroyProgressDialog();
-		ErrorMessage("Thread creation failed : RandomSearch");
-	}
+	if (t == NULL) ErrorMessage("Thread creation failed : RandomSearch");
 	
 #else	// ENABLE_THREADS
 	
@@ -302,31 +279,33 @@ void gtk_project::start_job_RandomSearch(jobinfo_RandomSearch * ji)
 
 gpointer gtk_project::process_job_RandomSearch(gpointer p)
 {
+	project::background_job_running = true;
 	jobinfo_RandomSearch * ji = (jobinfo_RandomSearch *) p;
 	
+	ji->prj->ThreadLock();
+	ji->prj->CreateProgressDialog("Random Search", true, NOT_DEFINED, NOT_DEFINED);
+	ji->prj->ThreadUnlock();
+	
 #ifdef ENABLE_THREADS
-	
 	const bool updt = false;
-	
 #else	// ENABLE_THREADS
-	
 	const bool updt = true;
-	
 #endif	// ENABLE_THREADS
 	
 	ji->prj->DoRandomSearch(ji->cycles, ji->optsteps, updt);
 	
-#ifdef ENABLE_THREADS
-	
 	ji->prj->ThreadLock();
 	ji->prj->DestroyProgressDialog();
 	ji->prj->ThreadUnlock();
 	
-#endif	// ENABLE_THREADS
-	
+	project::background_job_running = false;
 	return NULL;
 }
 
+// the other computation tasks are not yet multithreaded, but the above template can be used...
+// the other computation tasks are not yet multithreaded, but the above template can be used...
+// the other computation tasks are not yet multithreaded, but the above template can be used...
+
 base_wnd * gtk_project::CreateGraphicsWnd(bool detached)
 {
 //cout << "gtk_project::CreateGraphicsWnd()" << endl;
@@ -499,7 +478,7 @@ void gtk_project::popup_FileExport(GtkWidget *, gpointer data)
 	if (prj) new gtk_file_export_dialog(prj);
 }
 
-void gtk_project::popup_FileExportGraphic(GtkWidget *, gpointer data)
+void gtk_project::popup_FileExportGraphics(GtkWidget *, gpointer data)
 {
 	gtk_project * prj = gtk_app::GetPrjX();
 	
@@ -507,14 +486,6 @@ void gtk_project::popup_FileExportGraphic(GtkWidget *, gpointer data)
 	if (prj) new gtk_file_save_graphics_dialog(prj);
 }
 
-void gtk_project::popup_FileSaveAs(GtkWidget *, gpointer data)
-{
-	gtk_project * prj = gtk_app::GetPrjX();
-	
-	// will call delete itself...
-	if (prj) new gtk_file_save_dialog(prj);
-}
-
 void gtk_project::popup_FileExtra1(GtkWidget *, gpointer data)
 {
 	gtk_project * prj = gtk_app::GetPrjX();
@@ -527,6 +498,10 @@ void gtk_project::popup_FileExtra2(GtkWidget *, gpointer data)
 {
 	gtk_project * prj = gtk_app::GetPrjX();
 	
+// this is just a stub for a new "extra"-item...
+// this is just a stub for a new "extra"-item...
+// this is just a stub for a new "extra"-item...
+	
 	if (prj)
 	{
 		prj->Message("not implemented...");
@@ -1036,6 +1011,7 @@ void gtk_project::popup_CompGeomOpt(GtkWidget *, gpointer data)
 		
 		ji.prj = prj;
 		ji.go = geomopt_param(su);
+		ji.show_dialog = true;
 		
 		prj->start_job_GeomOpt(& ji);
 	}
@@ -1051,6 +1027,7 @@ void gtk_project::popup_CompMolDyn(GtkWidget *, gpointer data)
 		
 		ji.prj = prj;
 		ji.md = moldyn_param(su);
+		ji.show_dialog = true;
 		
 		prj->start_job_MolDyn(& ji);
 	}
