@@ -2,8 +2,19 @@
 
 // Copyright (C) 2005 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -23,7 +34,7 @@ bool oglview_wcl::quick_update = false;
 bool oglview_wcl::draw_info = true;
 
 oglview_wcl::oglview_wcl(custom_camera * cc) :
-	base_wcl(cc)
+	pangofont_wcl(cc)
 {
 	ccam = cc;
 	my_wnd_number = (ccam->wcl_counter++) + 1;
@@ -880,7 +891,7 @@ void oglview_wcl::MyUpdateWnd(pmode pm, int x, int y)
 
 void oglview_wcl::InitGL(void)
 {
-        const fGL background[4] = { 0.0, 0.0, 0.0, 1.0};
+	const fGL background[4] = { 0.0, 0.0, 0.0, 1.0};
 	glClearColor(background[0], background[1], background[2], background[3]);
 	
 	glDepthFunc(GL_LESS); glEnable(GL_DEPTH_TEST);
@@ -911,6 +922,11 @@ void oglview_wcl::InitGL(void)
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	
 	base_app::GetAppB()->SetupLights(ccam);
+	
+	// all classes that inherit pangofont_wcl must call ogl_InitPangoFont()!!!
+	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	
+	ogl_InitPangoFont("courier 12");
 }
 
 void oglview_wcl::RenderGL(rmode rm)
